@@ -33,9 +33,9 @@ def url_to_module(url):
         'google': google,
         'iask': sina,
         'ifeng': ifeng,
+        'in': alive,
         'iqiyi': iqiyi,
         'joy': joy,
-        'jpopsuki': jpopsuki,
         'kankanews': bilibili,
         'ku6': ku6,
         'miomio': miomio,
