@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 from .acfun import *
+from .alive import *
 from .baidu import *
 from .bilibili import *
 from .blip import *
@@ -14,7 +15,6 @@ from .google import *
 from .ifeng import *
 from .iqiyi import *
 from .joy import *
-from .jpopsuki import *
 from .ku6 import *
 from .miomio import *
 from .mixcloud import *
